@@ -46,7 +46,7 @@ gcpReaction::~gcpReaction ()
 	gcpReactionArrow *arrow;
 	gcpDocument *pDoc = reinterpret_cast<gcpDocument *> (GetDocument ());
 	gcpOperation *pOp = pDoc->GetCurrentOperation ();
-	while (pObj = GetFirstChild (i)) {
+	while ((pObj = GetFirstChild (i))) {
 		if (pObj->GetType () == ReactionArrowType) {
 			arrow = reinterpret_cast<gcpReactionArrow*> (pObj);
 			arrow->SetStartStep (NULL);
