@@ -164,33 +164,33 @@ void on_receive(GtkClipboard *clipboard, GtkSelectionData *selection_data, gcpVi
 
 using namespace std;
 
-gcpView::gcpView(gcpDocument *pDoc, bool Embedded)
+gcpView::gcpView (gcpDocument *pDoc, bool Embedded)
 {
 	m_pDoc = pDoc;
-	m_PangoFontDesc = pango_font_description_new();
-	pango_font_description_set_family(m_PangoFontDesc, DefaultFontFamily);
-	pango_font_description_set_style(m_PangoFontDesc, DefaultFontStyle);
-	pango_font_description_set_weight(m_PangoFontDesc, DefaultFontWeight);
-	pango_font_description_set_variant(m_PangoFontDesc, DefaultFontVariant);
-	pango_font_description_set_stretch(m_PangoFontDesc, DefaultFontStretch);
-	pango_font_description_set_size(m_PangoFontDesc, DefaultFontSize);
-	m_sFontName = pango_font_description_to_string(m_PangoFontDesc);
-	m_PangoSmallFontDesc = pango_font_description_new();
-	pango_font_description_set_family(m_PangoSmallFontDesc, DefaultFontFamily);
-	pango_font_description_set_style(m_PangoSmallFontDesc, DefaultFontStyle);
-	pango_font_description_set_weight(m_PangoSmallFontDesc, DefaultFontWeight);
-	pango_font_description_set_variant(m_PangoSmallFontDesc, DefaultFontVariant);
-	pango_font_description_set_stretch(m_PangoSmallFontDesc, DefaultFontStretch);
-	pango_font_description_set_size(m_PangoSmallFontDesc, DefaultFontSize * 2 / 3);
-	m_sSmallFontName = pango_font_description_to_string(m_PangoSmallFontDesc);
-	m_PangoTinyFontDesc = pango_font_description_new();
-	pango_font_description_set_family(m_PangoTinyFontDesc, DefaultFontFamily);
-	pango_font_description_set_style(m_PangoTinyFontDesc, DefaultFontStyle);
-	pango_font_description_set_weight(m_PangoTinyFontDesc, DefaultFontWeight);
-	pango_font_description_set_variant(m_PangoTinyFontDesc, DefaultFontVariant);
-	pango_font_description_set_stretch(m_PangoTinyFontDesc, DefaultFontStretch);
-	pango_font_description_set_size(m_PangoTinyFontDesc, DefaultFontSize / 2);
-	m_sTinyFontName = pango_font_description_to_string(m_PangoTinyFontDesc);
+	m_PangoFontDesc = pango_font_description_new ();
+	pango_font_description_set_family (m_PangoFontDesc, DefaultFontFamily);
+	pango_font_description_set_style (m_PangoFontDesc, DefaultFontStyle);
+	pango_font_description_set_weight (m_PangoFontDesc, DefaultFontWeight);
+	pango_font_description_set_variant (m_PangoFontDesc, DefaultFontVariant);
+	pango_font_description_set_stretch (m_PangoFontDesc, DefaultFontStretch);
+	pango_font_description_set_size (m_PangoFontDesc, DefaultFontSize);
+	m_sFontName = pango_font_description_to_string (m_PangoFontDesc);
+	m_PangoSmallFontDesc = pango_font_description_new ();
+	pango_font_description_set_family (m_PangoSmallFontDesc, DefaultFontFamily);
+	pango_font_description_set_style (m_PangoSmallFontDesc, DefaultFontStyle);
+	pango_font_description_set_weight (m_PangoSmallFontDesc, DefaultFontWeight);
+	pango_font_description_set_variant (m_PangoSmallFontDesc, DefaultFontVariant);
+	pango_font_description_set_stretch (m_PangoSmallFontDesc, DefaultFontStretch);
+	pango_font_description_set_size (m_PangoSmallFontDesc, DefaultFontSize * 2 / 3);
+	m_sSmallFontName = pango_font_description_to_string (m_PangoSmallFontDesc);
+	m_PangoTinyFontDesc = pango_font_description_new ();
+	pango_font_description_set_family (m_PangoTinyFontDesc, DefaultFontFamily);
+	pango_font_description_set_style (m_PangoTinyFontDesc, DefaultFontStyle);
+	pango_font_description_set_weight (m_PangoTinyFontDesc, DefaultFontWeight);
+	pango_font_description_set_variant (m_PangoTinyFontDesc, DefaultFontVariant);
+	pango_font_description_set_stretch (m_PangoTinyFontDesc, DefaultFontStretch);
+	pango_font_description_set_size (m_PangoTinyFontDesc, DefaultFontSize / 2);
+	m_sTinyFontName = pango_font_description_to_string (m_PangoTinyFontDesc);
 	m_DefaultPadding = DefaultPadding;
 	m_DefaultStereoBondWidth = DefaultStereoBondWidth;
 	m_DefaultHashWidth = DefaultHashWidth;
@@ -210,16 +210,22 @@ gcpView::gcpView(gcpDocument *pDoc, bool Embedded)
 	m_width = 400;
 	m_height = 300;
 	m_ActiveRichText = NULL;
-	if (!(m_bEmbedded = Embedded)) CreateNewWidget();
+	if (!(m_bEmbedded = Embedded))
+		CreateNewWidget ();
 	m_UIManager = gtk_ui_manager_new ();
 	m_Dragging = false;
 }
 
-gcpView::~gcpView()
+gcpView::~gcpView ()
 {
-	g_object_unref(G_OBJECT(m_PangoContext));
-	if (m_sFontName) g_free(m_sFontName);
-	if (m_sSmallFontName) g_free(m_sSmallFontName);
+	g_object_unref (G_OBJECT (m_PangoContext));
+	if (m_sFontName)
+		g_free (m_sFontName);
+	if (m_sSmallFontName)
+		g_free (m_sSmallFontName);
+	pango_font_description_free (m_PangoFontDesc);
+	pango_font_description_free (m_PangoSmallFontDesc);
+	pango_font_description_free (m_PangoTinyFontDesc);
 	g_object_unref (m_UIManager);
 }
 
@@ -308,7 +314,7 @@ bool gcpView::OnEvent(GnomeCanvasItem *item, GdkEvent *event, GtkWidget* widget)
 		pActiveTool->OnDrag(x, y, event->button.state);
 		return true;
 	case GDK_BUTTON_RELEASE:
-	switch (event->button.button)
+		switch (event->button.button)
 		{
 		case 1:
 			if (!m_Dragging) break;
@@ -316,10 +322,15 @@ bool gcpView::OnEvent(GnomeCanvasItem *item, GdkEvent *event, GtkWidget* widget)
 			pActiveTool->OnRelease(x, y, event->button.state);
 			m_pDoc->GetApplication()->ClearStatus();
 			return true;
+		default:
+			break;
 		}
 		break;
+	default:
+		break;
 	}
 	return false;
+	
 }
 
 void gcpView::AddObject(Object* pObject)
@@ -361,12 +372,8 @@ GtkWidget* gcpView::CreateNewWidget()
 		m_pData->StereoBondWidth = m_DefaultStereoBondWidth * DefaultZoomFactor;
 		m_pData->ObjectPadding = m_DefaultObjectPadding * DefaultZoomFactor;
 		m_pData->SignPadding = m_DefaultSignPadding * DefaultZoomFactor;
-		m_pData->Group = GNOME_CANVAS_GROUP (gnome_canvas_item_new (
-									gnome_canvas_root(GNOME_CANVAS(m_pWidget)),
-									gnome_canvas_group_ext_get_type (),
-									NULL));
 		m_pData->Background = gnome_canvas_item_new(
-									m_pData->Group,
+									gnome_canvas_root(GNOME_CANVAS(m_pWidget)),
 									gnome_canvas_rect_get_type(),
 									"x1", 0.0,
 									"y1", 0.0,
@@ -374,6 +381,10 @@ GtkWidget* gcpView::CreateNewWidget()
 									"y2", (double) m_height,
 									"fill_color", "white",
 									NULL);
+		m_pData->Group = GNOME_CANVAS_GROUP (gnome_canvas_item_new (
+									gnome_canvas_root(GNOME_CANVAS(m_pWidget)),
+									gnome_canvas_group_ext_get_type (),
+									NULL));
 		g_signal_connect(G_OBJECT(m_pData->Background), "event", G_CALLBACK(on_event), m_pWidget);
 		g_signal_connect(G_OBJECT(m_pWidget), "destroy", G_CALLBACK(on_destroy), this);
 		g_signal_connect(G_OBJECT(m_pWidget), "size_allocate", G_CALLBACK(on_size), this);
@@ -484,8 +495,6 @@ void gcpView::UpdateFont()
 	pl = pango_layout_new(m_PangoContext);
 	pango_layout_set_text(pl, "C", 1);
 	pango_layout_get_extents(pl, &rect, NULL);
-	PangoLayoutIter* iter = pango_layout_get_iter(pl);
-	double ascent = pango_layout_iter_get_baseline(iter) / PANGO_SCALE;
 	m_BaseLineOffset =  (double(rect.height / PANGO_SCALE) / 2.0) / DefaultZoomFactor;
 	g_object_unref(G_OBJECT(pl));
 }
@@ -591,12 +600,10 @@ void gcpView::OnReceive(GtkClipboard* clipboard, GtkSelectionData* selection_dat
 	guint *DataType = (clipboard == gtk_clipboard_get(GDK_SELECTION_CLIPBOARD))? &ClipboardDataType: &ClipboardDataType1;
 	g_return_if_fail((selection_data->target == gdk_atom_intern (targets[*DataType].target, FALSE)));
 	if (pActiveTool->OnReceive(clipboard, selection_data, *DataType)) return;
-//	if (ToolsDlg) ToolsDlg->Select(SelectId);
-	else if (pActiveTool/* && pActiveTool->Activate(false)*/)
+	else if (pActiveTool)
 	{
 		pApp->ActivateTool("Select", true);
 		pActiveTool = pApp->GetActiveTool();
-//		if (pActiveTool) pActiveTool->Activate(true);
 	}
 	if (!pActiveTool || (pActiveTool != pApp->GetTool("Select"))) return;
 	xmlDocPtr xml;
@@ -639,7 +646,7 @@ void gcpView::OnReceive(GtkClipboard* clipboard, GtkSelectionData* selection_dat
 				gtk_text_buffer_get_bounds(buf, &start, &end);
 				gtk_text_buffer_remove_all_tags(buf, &start, &end);
 				gtk_text_buffer_apply_tag_by_name(buf, pApp->GetFontName(), &start, &end);
-				text->OnEndUserAction(buf);
+				text->OnChanged(buf);
 				m_pDoc->AddObject(text);
 				m_pData->SetSelected(text);
 			}
@@ -769,7 +776,6 @@ bool gcpView::OnSize(int width, int height)
 {
 	if ((width == m_width) && (height == m_height)) return true;
 	std::list<GtkWidget*>::iterator i;
-	int x, y;
 	m_height = height;
 	m_width = width;
 	for (i = m_Widgets.begin(); i != m_Widgets.end(); i++)
@@ -831,7 +837,7 @@ void gcpView::ExportImage (const char* filename, const char* type)
 	ArtDRect rect;
 	m_pData->GetObjectBounds (m_pDoc, &rect);
 	m_pData->ShowSelection (false);
-	int w = (int) (floor (rect.x1) - ceil (rect.x0)) + 1, h = (int) (floor (rect.y1) - ceil (rect.y0));
+	int w = (int) (ceil (rect.x1) - floor (rect.x0)), h = (int) (ceil (rect.y1) - floor (rect.y0));
 	if (!strcmp (type, "eps")) {
 		GnomePrintConfig* config = gnome_print_config_default();
 		GnomePrintContext *pc;
@@ -912,7 +918,6 @@ void gcpView::ExportImage (const char* filename, const char* type)
 						GdkPixbuf *pixbuf = gdk_pixbuf_new (GDK_COLORSPACE_RGB, FALSE, 8, w, h);
 						GnomeCanvasBuf cbuf;
 						int i, j, mask, lines, bytes;
-						unsigned char b;
 						cbuf.buf = gdk_pixbuf_get_pixels (pixbuf);
 						cbuf.rect.x0 = (int) floor (rect.x0);
 						cbuf.rect.x1 = (int) ceil (rect.x1);
